@@ -89,7 +89,8 @@ wrapTTest.htest <- function(x,
 #' @param x data.frame
 #' @param Column1Name character column 1 name
 #' @param Column2Name character column 2 name
-#' @param ... extra arguments
+#' @param ... extra arguments passed to ttest
+#' @param na.rm logical, if TRUE remove NA values
 #' @return formatted string and fields
 #'
 #' @examples
@@ -106,7 +107,8 @@ wrapTTest.htest <- function(x,
 wrapTTest.data.frame <- function(x,
                                  Column1Name,
                                  Column2Name,
-                            ...) {
+                                 ...,
+                                 na.rm= FALSE) {
   if(!'data.frame' %in% class(x)) {
     stop('sigr::wrapTTest expected class data.frame')
   }
@@ -116,11 +118,22 @@ wrapTTest.data.frame <- function(x,
   if(!is.numeric(x[[Column2Name]])) {
     stop("sigr::wrapTTest expected column 2 to be numeric")
   }
-  tt <- t.test(x[[Column1Name]],x[[Column2Name]],...)
+  c1 <- x[[Column1Name]]
+  c2 <- x[[Column2Name]]
+  nNA <- sum(is.na(c1) | is.na(c2))
+  if(na.rm) {
+    goodPosns <- (!is.na(c1)) & (!is.na(c2))
+    c1 <- c1[goodPosns]
+    c2 <- c2[goodPosns]
+  }
+  n <- length(c1)
+  tt <- t.test(c1,c2,...)
   r <- list(tt=tt,
             test='t.test',
             Column1Name=Column1Name,
-            Column2Name=Column2Name)
+            Column2Name=Column2Name,
+            n=n,
+            nNA=nNA)
   class(r) <- c('sigr_ttest', 'sigr_statistic')
   r
 }
